@@ -6,8 +6,13 @@
 done=0
 trap 'done=1' TERM INT
 
+UWSGI_ADD_OPTIONS=""
+if [ -n "$MAPPROXY_ALPINE" ]; then
+  UWSGI_ADD_OPTIONS="--plugin python3"
+fi
+
 # run uswgi and nginx in parallel
-uwsgi --ini /mapproxy/uwsgi.conf &
+uwsgi $UWSGI_ADD_OPTIONS --ini /mapproxy/uwsgi.conf &
 echo "uswgi started"
 nginx &
 echo "nginx started"
