@@ -17,10 +17,13 @@ from __future__ import division
 
 import logging
 import os
-import importlib_resources
+from PIL import Image, ImageColor, ImageDraw, ImageFont
+try:
+    import importlib_resources
+except ImportError:
+    from importlib import resources as importlib_resources
 
 from mapproxy.config import base_config, abspath
-from mapproxy.compat.image import Image, ImageColor, ImageDraw, ImageFont
 from mapproxy.image import ImageSource
 from mapproxy.image.opts import create_image, ImageOptions
 
@@ -289,7 +292,7 @@ class TextDraw(object):
                 text_box = draw.textbbox((0, y_offset), line, font=self.font)
                 y_offset = text_box[3] + self.linespacing
             except AttributeError:
-                # Pillow < 8
+                # Some Pillow versions do not support textbox for non true type fonts
                 text_size = draw.textsize(line, font=self.font)
                 text_box = (0, y_offset, text_size[0], text_size[1]+y_offset)
                 y_offset += text_size[1] + self.linespacing
