@@ -25,7 +25,7 @@ from io import BytesIO
 import pytest
 
 from mapproxy.request.wms import WMS111MapRequest
-from mapproxy.compat.image import Image
+from PIL import Image
 from mapproxy.test.image import is_png
 from mapproxy.test.system import SysTest
 
@@ -40,7 +40,6 @@ def config_file():
     return "mapserver.yaml"
 
 
-@pytest.mark.skipif(sys.version_info < (3, 0), reason="tests skipped for python 2")
 class TestMapServerCGI(SysTest):
 
     @pytest.fixture(scope="class")
