@@ -14,7 +14,6 @@
 # limitations under the License.
 
 import os
-import sqlite3
 import threading
 import time
 
@@ -26,6 +25,7 @@ from mapproxy.image import ImageSource
 from mapproxy.test.helper import assert_files_in_dir, assert_permissions
 from mapproxy.test.image import create_tmp_image_buf
 from mapproxy.test.unit.test_cache_tile import TileCacheTestBase
+from mapproxy.util.sqlite3 import sqlite3
 
 tile_image = create_tmp_image_buf((256, 256), color='blue')
 tile_image2 = create_tmp_image_buf((256, 256), color='red')
@@ -109,24 +109,24 @@ class TestMBTileLevelCache(TileCacheTestBase):
         assert_files_in_dir(self.cache_dir, [])
 
         self.cache.store_tile(self.create_tile((0, 0, 1)))
-        assert_files_in_dir(self.cache_dir, ['1.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['1.mbtiles'], glob='*.mbtiles')
 
         self.cache.store_tile(self.create_tile((0, 0, 5)))
-        assert_files_in_dir(self.cache_dir, ['1.mbtile', '5.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['1.mbtiles', '5.mbtiles'], glob='*.mbtiles')
 
     def test_remove_level_files(self):
         self.cache.store_tile(self.create_tile((0, 0, 1)))
         self.cache.store_tile(self.create_tile((0, 0, 2)))
-        assert_files_in_dir(self.cache_dir, ['1.mbtile', '2.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['1.mbtiles', '2.mbtiles'], glob='*.mbtiles')
 
         self.cache.remove_level_tiles_before(1, remove_all=True)
-        assert_files_in_dir(self.cache_dir, ['2.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['2.mbtiles'], glob='*.mbtiles')
 
     def test_remove_level_tiles_before(self):
         self.cache.store_tile(self.create_tile((0, 0, 1)))
         self.cache.store_tile(self.create_tile((0, 0, 2)))
 
-        assert_files_in_dir(self.cache_dir, ['1.mbtile', '2.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['1.mbtiles', '2.mbtiles'], glob='*.mbtiles')
         assert self.cache.is_cached(Tile((0, 0, 1)))
 
         self.cache.remove_level_tiles_before(1, timestamp=time.time() - 60)
@@ -135,7 +135,7 @@ class TestMBTileLevelCache(TileCacheTestBase):
         self.cache.remove_level_tiles_before(1, timestamp=time.time() + 60)
         assert not self.cache.is_cached(Tile((0, 0, 1)))
 
-        assert_files_in_dir(self.cache_dir, ['1.mbtile', '2.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['1.mbtiles', '2.mbtiles'], glob='*.mbtiles')
         assert self.cache.is_cached(Tile((0, 0, 2)))
 
     def test_bulk_store_tiles_with_different_levels(self):
@@ -146,7 +146,7 @@ class TestMBTileLevelCache(TileCacheTestBase):
             self.create_tile((1, 0, 1)),
         ], dimensions=None)
 
-        assert_files_in_dir(self.cache_dir, ['1.mbtile', '2.mbtile'], glob='*.mbtile')
+        assert_files_in_dir(self.cache_dir, ['1.mbtiles', '2.mbtiles'], glob='*.mbtiles')
         assert self.cache.is_cached(Tile((0, 0, 1)))
         assert self.cache.is_cached(Tile((1, 0, 1)))
         assert self.cache.is_cached(Tile((0, 0, 2)))
