@@ -13,8 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from mapproxy.compat.image import Image
-from mapproxy.grid import tile_grid
+from collections import OrderedDict
+
+from PIL import Image
+from mapproxy.grid.tile_grid import tile_grid
 from mapproxy.image import BlankImageSource
 from mapproxy.image import ImageSource
 from mapproxy.image.opts import ImageOptions
@@ -24,7 +26,6 @@ from mapproxy.service.tile import TileServer
 from mapproxy.service.wms import WMSGroupLayer, WMSServer
 from mapproxy.service.wmts import WMTSServer
 from mapproxy.test.http import make_wsgi_env
-from mapproxy.util.ext.odict import odict
 
 
 class DummyLayer(MapLayer):
@@ -38,6 +39,7 @@ class DummyLayer(MapLayer):
         self.name = name
         self.requested = False
         self.queried = False
+        self.nominal_scale = None
 
     def get_map(self, query):
         self.requested = True
@@ -81,7 +83,7 @@ class TestDecorateImg(object):
             image_formats={'image/png': ImageOptions(format='image/png')}
         )
         # Tile Servers
-        layers = odict()
+        layers = OrderedDict()
         layers["wms_cache_EPSG900913"] = DummyTileLayer('wms_cache')
         self.tile_server = TileServer(layers, {})
         self.wmts_server = WMTSServer(layers, {})
