@@ -24,14 +24,14 @@ import shapely
 import shapely.prepared
 from shapely.errors import ShapelyError
 
-from mapproxy.srs import SRS, bbox_equals
+from mapproxy.srs import SRS
+from mapproxy.util.bbox import bbox_equals
 from mapproxy.util.geom import (
     load_polygons,
     load_datasource,
     load_geojson,
     load_expire_tiles,
     transform_geometry,
-    geom_support,
     bbox_polygon,
     build_multipolygon,
 )
@@ -46,9 +46,6 @@ from mapproxy.layer import MapExtent, DefaultMapExtent
 from mapproxy.test.helper import TempFile
 from mapproxy.util.coverage import BBOXCoverage
 
-pytestmark = pytest.mark.skipif(not geom_support,
-                                reason="requires Shapely")
-
 
 VALID_POLYGON1 = b"""POLYGON ((953296.704552185838111 7265916.626927595585585,
 944916.907243740395643 7266183.505430161952972,
