@@ -16,7 +16,7 @@
 
 from __future__ import print_function
 
-from mapproxy.compat.image import Image, ImageDraw, ImageColor, ImageFont
+from PIL import Image, ImageDraw, ImageColor, ImageFont
 from mapproxy.cache.tile import Tile
 from mapproxy.image import ImageSource
 from mapproxy.image.message import TextDraw, message_image
@@ -31,6 +31,7 @@ requires_freetype = pytest.mark.skipif(
     not isinstance(ImageFont.load_default(), ImageFont.FreeTypeFont),
     reason="Test expects the default Pillow FreeTypeFont")
 
+
 class TestTextDraw(object):
 
     def test_ul(self):
